pub enum CollectionDiffEntry<T: Diffable> {
Removed(T),
Added(T),
Changed(<T as Diffable>::Repr),
Unchanged,
}Expand description
Enum representing a difference in collections such as HashMap or Vec.
Variants
Removed(T)
Indicates that an item was removed from the collection.
Added(T)
Indicates that an item was added to the collection.
Changed(<T as Diffable>::Repr)
Indicates that an item has changed.
Unchanged
Indicates that an item has not changed.