pub trait Diffable {
type Repr: Changeable + Debug + for<'de> MySerialize<'de>;
// Required method
fn diff(&self, b: &Self) -> Self::Repr;
}Expand description
Trait representing the ability to compute a difference between two objects.
Required Associated Types
Sourcetype Repr: Changeable + Debug + for<'de> MySerialize<'de>
type Repr: Changeable + Debug + for<'de> MySerialize<'de>
The type used to represent the difference between two objects.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.